function files=readListOfFiles(filename='wfmfiles.txt')
% function files=readListOfFiles(filename='wfmfiles.txt')
% generates a cell array files with a list of /pth/files from contents
% of wfmfiles.txt and passes the list to readListOfFilesAndDisplayFirst.m
% to read the 1st event and display the waveform for each file in the list.
%
% run on Matlab as: matlab -nosplash -nodesktop -r readListOfFiles
% run on Octave as:	octave --persist
%			> readListOfFiles
% or			> readListOfFiles('wfmfiles.txt')
% where wfmfiles.txt is a 1 column list of /path/filename files.
% to generate a 1 column list for files with complete path 
% use eg 'ls -1 /path/* > wfmfiles.txt'

global debugLevel;
debugLevel = 0;


% linux standard stdout=1 stderr=2
stdout=1;	%need for matlab
stderr=2;	%need for matlab

% the text file wfmfiles.txt contains a list of .wfm files as
% /path/file.wfm 
% one file per line

[status, output]=system('uname');
if status ~= 0
	fprintf(stderr, 'Failed to get type of operating system! Exit.\n');
	exit
end
ostype = output;

% this may be a file system pointer to a real file
if nargin < 1; filename='wfmfiles.txt'; end;
fileID = fopen(filename);
if fileID == -1 
	fprintf(stderr, 'file %s not found, exit...\n', filename)
	exit
end
%
% get the count of files in filename
if strcmp( ostype, ['Linux' 10] ) == 1						% decimal 10 = '\n' 
	cmd1=sprintf('wc -l %s | cut -d" " -f 1',filename);			% Linux version
	[status, output]=system(cmd1);
elseif strcmp( ostype, ['Darwin' 10] ) == 1
	cmd1=sprintf('wc -l wfmfiles.txt | tr -s " " | cut -d " " -f 1,2',filename); % Mac OS X
	[status, output]=system(cmd1);
else
	status = -1;
end
	
if status ~= 0 
	fprintf(stderr, 'Failed to get line count from file %s, so exit\n', filename);
	exit
end
linecount=str2num(output);
fprintf(stdout, 'number of lines in file %s is %d\n', filename, linecount);

% build a list of files to send to reader.
for i=1:linecount
        file=fgetl(fileID);
	%print_object_properties(file,'file');
        if file == -1; break; end;	% check for EOF
        %files(i,:)=file;
        files{i}=file;
end
contentsOf_files=files;
fclose(fileID);

% ok we now have the list of files in the variable files
% pass it to readListOfFilesAndDisplayFirst

%
% read files from list 'files', uses readlistoffiles.m which calls wfm2readframe.m to do the work
% plot 1st wfm from each file
%frameSupport=0;	% single frame reader
%frameSupport=1;  	% fastframes reader
frameSupport=2;  	% read a single frame via wfm2readframe.m
[x,t]=readListOfFilesAndDisplayFirst(files,frameSupport);	% Will read the list of files and plot 1st event in each file

%reprise
contentsOf_files=files;

fprintf(1,'\nThats All, Folk!\nThe End.\n\n');

