function[x,t]=readListOfFilesAndDisplayFirst(files,frameSupport=2);
% reads and plots 1st event from each .wfm for a list of files
% function[x,t]=readListOfFilesAndDisplayFirst(files,frameSupport=2)
% Input arguements: files : a cell array storing variable length character
%	stings with /path/filename
% Input arguements" frameSupport : specifiest which method (and function) to
%	read the .wfm file with  default = 2 uses wfm2readframe.m
% frameSupport=0 reads single frame files of type :WFM#001
% frameSupport=1 reads single type :WFM#001 and fast frame files of type :WFM#003
% frameSupport=2 reads single and fast frame files of type :WFM#001 and :WFM#003

%warning('off');
global debugLevel;
n = size(files,2);		% note files is a cell array ie storing variable length character strings
for ifile = 1:n
    figNumber = ifile;
    %filename=files(ifile,:);
    filename=files{ifile};	% note {} braces
    %fprintf(1,'In readlistoffiles.m: Reading file = %s\n',filename)
    clear x t info ind_over ind_under frames	% could be different sizes!
    if ( frameSupport == 2 )
        frame=1;
        [x(ifile,:), t, info, ind_over, ind_under] = wfm2readframe(filename, frame);
       if debugLevel >= 1
          print_object_properties(info,'info');
          contentsOf_info=info
          print_object_properties(frames,'frames');
          lengthOf_frames=length(frames)
          %contentsOf_frames=frames	% could be long
          fprintf(1,'TEK file type: versioning_number = %s\n', info.versioning_number);
          fprintf(1,'Number of fast frames = %d\n',info.num_acq_fast_frames);
	  print_object_properties(info.versioning_number, 'info.versioning_number')
	  print_object_properties(info.num_acq_fast_frames, 'info.num_acq_fast_frames')
	  print_object_properties(1, '1')
       end
       ftype{ifile}=info.versioning_number;
       ffrmcnt(ifile)=info.num_acq_fast_frames;
       if strcmp( ':WFM#001', info.versioning_number ) == 1;  ffrmcnt(ifile) = 1; end;
       [pointsPerFrame,dummy]=size(t);
       fptsPerFrame(ifile)=pointsPerFrame;
    end
    if ( frameSupport == 1 )
       % this reads the entire file, so can be slow
       [x(ifile,:), t,info, ind_over, ind_under, frames]=wfm2read(filename);
       if debugLevel >= 1
          print_object_properties(info,'info');
          contentsOf_info=info
          print_object_properties(frames,'frames');
          lengthOf_frames=length(frames)
          %contentsOf_frames=frames	% could be long
       end
       fprintf(1,'TEK file type: versioning_number = %s\n', info.versioning_number);
       fprintf(1,'Number of fast frames = %d\n',info.num_acq_fast_frames);
    end
    if ( frameSupport == 0 )
	[x(ifile,:), t]=wfm2read(filename);
    end

    %fprintf(1,'In readfiles.m: sixe of t = %d %d\n', size(t))
    %fprintf(1,'In readfiles.m: size of x = %d %d\n', size(x))
    %fprintf(1,'In readfiles.m: time step = %g \n', t(2,1)-t(1,1));
    slabel1 = sprintf('Time step = %g (pscec)\n', 1.0e+12 * (t(2,1)-t(1,1)) );
    %plot(x(filei,:));
    scalet = 1.0e+9;	% nsec ie convert absolute time from seconds to nanosec
    ftimeStep(ifile)=scalet*((t(2,1)-t(1,1)) );
    if  ifile < 25 || ifile > n-25	% limit to 1st five and last five of a large list 
        figure(figNumber);
	plot( scalet*t(:,1),x(ifile,:) );
        a=axis();				% get the positions of 4 corners of lot
        %fprintf(1,'axis limits : %f %f %f %f\n', a(1), a(2),a(3), a(4) );
        text( (a(2)+a(1))/2, a(3) + 0.9*(a(4)-a(3)), slabel1 );
        %fprintf(1,'text posistion : %f %f \n',  (a(2)+a(1))/2,  a(3) + 0.9*(a(4)-a(3)) );
    end
    xlabel( 'time (nsec)');
    ylabel( 'Voltage (V)');
    stitle = sprintf('waveform from file %s', filename);
    title( stitle );	%note this causes the warning message 'setting font to ,12'
    %hold on
end %end of loop over files.

    fprintf(1,'\n\tSummary\n');
    fprintf(1,'file#\tNumber\t\t(nsec)\tPts in\n');
    fprintf(1,'\tframes\tType    TimeStep Frame Name\n');
    for ifile = 1:n
	fprintf(1,'%d\t%d\t%s %f %d %s\n', ifile,ffrmcnt(ifile), ftype{ifile}, ftimeStep(ifile),fptsPerFrame(ifile),files{ifile})
    end
