function [x,t]=readMultipleEventsFromAFile(nevents,file,frameSupport, datapoints=-1, step=1, startind=1);
%
%function [x,t]=readMultipleEventsFromAFile(nevents,file,frameSupport, datapoints=-1, step=1, startind=1);
% reads the first nevents from the file name 'file' for the supported frameSupport formats, plots 
% each event in a framenumbered window, builds and plot the Or of the nevents and average shape in
% figures 2001 and 2002. Time is scaled to nanosec for plots. Optional parameters datapoints, step, startind
% allow a slice of each frame data to be displayed. A one line summary of the file is given at the end.
% returned variables x,t contain the selected events.
% figure(3000); plot(t,x) will reshow the data of the OR.
% applying statistical functions min,mean,std,quantile to x may be useful.

%warning('off');
global debugLevel;
ifile = 1;
frameCount=0;
for frame = 1:nevents
    figNumber = frame;
    filename=file;
    %fprintf(1,'In readlistoffiles.m: Reading file = %s\n',filename)
    if ( frameSupport == 2 )
        %[x(:,frame), t(:,frame), info, ind_over, ind_under] = wfm2readframe(filename, frame);
	if datapoints == -1 
	   % take all datapoints in curve.
           [x(:,frame), t(:,frame), info, ind_over, ind_under] = wfm2readframe(filename, frame);
	else
           [x(:,frame), t(:,frame), info, ind_over, ind_under] = wfm2readframe(filename, frame, datapoints, step, startind );
	end
        %[y, ty, info, ind_over, ind_under] = wfm2readframe(filename, frame);
	%fprintf(1,'size of y=%d %d size of ty=%d %d\n',size(y),size(ty));
	frameCount = frameCount+1;
        if frame >  info.num_acq_fast_frames; fframes = frameCount; break; end;
        if frame == 0; fframes = 1; ffrmcnt(1)=1; break; end;
       if debugLevel >= 1
          print_object_properties(info,'info');
          contentsOf_info=info
          print_object_properties(frames,'frames');
          lengthOf_frames=length(frames)
          %contentsOf_frames=frames	% could be long
          fprintf(1,'TEK file type: versioning_number = %s\n', info.versioning_number);
          fprintf(1,'Number of fast frames = %d\n',info.num_acq_fast_frames);
	  print_object_properties(info.versioning_number, 'info.versioning_number')
	  print_object_properties(info.num_acq_fast_frames, 'info.num_acq_fast_frames')
	  print_object_properties(1, '1')
       end
       ftype{ifile}=info.versioning_number;
       ffrmcnt(ifile)=info.num_acq_fast_frames;
    end
    if ( frameSupport == 1 )
       % may not want this
       [x(ifile,:), t,info, ind_over, ind_under, frames]=wfm2read(filename);
       if debugLevel >= 1
          print_object_properties(info,'info');
          contentsOf_info=info
          print_object_properties(frames,'frames');
          lengthOf_frames=length(frames)
          %contentsOf_frames=frames	% could be long
       end
       fprintf(1,'TEK file type: versioning_number = %s\n', info.versioning_number);
       fprintf(1,'Number of fast frames = %d\n',info.num_acq_fast_frames);
    end
    if ( frameSupport == 0 )
        % certainly do not want this
	[x(ifile,:), t]=wfm2read(filename);
    end
end % over frames
       fprintf(1,'info.versioning_number=%s\n', info.versioning_number);
       if strcmp( ':WFM#001', info.versioning_number ) == 1;  ftype{ifile} = ':WFM#001'; ffrmcnt(ifile) = 1; end;

    fprintf(1,'size of t = %d %d\n', size(t));
    fprintf(1,'frameCount=%d\n',frameCount);
    %fprintf(1,'In readfiles.m: time step = %g \n', t(2,1)-t(1,1));
    scalet = 1.0e+9;	% nsec ie convert absolute time from seconds to nanosec
    ftimeStep(ifile)=scalet*((t(2,1)-t(1,1)) );
    for frame =1:frameCount
      if  frame < 25 || frame > nevents-25	% limit to 1st twentyfive and last twentyfive of a large list 
        figure(frame);
        slabel1 = sprintf('Time step = %g (pscec)\n', 1.0e+12 * (t(2,frame)-t(1,frame)) );
	plot( scalet*t(:,frame),x(:,frame) );
        a=axis();				% get the positions of 4 corners of lot
        %fprintf(1,'axis limits : %f %f %f %f\n', a(1), a(2),a(3), a(4) );
        text( (a(2)+a(1))/2, a(3) + 0.9*(a(4)-a(3)), slabel1 );
        %fprintf(1,'text posistion : %f %f \n',  (a(2)+a(1))/2,  a(3) + 0.9*(a(4)-a(3)) );
      end
      xlabel( 'time (nsec)');
      ylabel( 'Voltage (V)');
      stitle = sprintf('waveform from file %s', filename);
      title( stitle );	%note this causes the warning message 'setting font to ,12'
    end
    % construct the OR of all plots and the average of all plots
    figure (2001);
    xave=zeros(length(x(:,1)),1);
    for frame =1:frameCount
	plot( scalet*t(:,frame),x(:,frame) );
	hold on;
	xave(:,1)=xave(:,1) + x(:,frame);
    end
    stitle=sprintf('Or of %d frames', frameCount);
    xlabel( 'time (nsec)');
    ylabel( 'Voltage (V)');
    title(stitle);
    hold off;
    figure(2002);
    plot(scalet*t(:,1), xave(:,1)/frameCount);
    stitle=sprintf('Average of %d frames',frameCount);
    title(stitle);
    xlabel( 'time (nsec)');
    ylabel( 'Voltage (V)');
    fprintf(1,'In readfiles.m: time step = %g \n', t(2,1)-t(1,1));
    fprintf(1,'In readfiles.m: size of x = %d %d\n',size(x));
    fprintf(1,'In readfiles.m: size of t = %d %d\n',size(t));
    [pointsPerFrame,numberOfFrames]=size(t);
    fprintf(1,'\n\tSummary\n');
    fprintf(1,'file#\tNumber\t\t(nsec)\tPts in\n');
    fprintf(1,'\tframes\tType    TimeStep Frame Name\n');
    for ifile = 1:1
	fprintf(1,'%d\t%d\t%s %6.4f %d %s\n', ifile,ffrmcnt(ifile), ftype{ifile}, ftimeStep(ifile),pointsPerFrame, file);
    end
